;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'idlwave-abbrev-and-indent-action '("idlwave"))
(custom-add-loads 'idlwave-shell-highlighting-and-faces '("idlw-shell"))
(custom-add-loads 'idlwave '("idlw-help" "idlw-shell" "idlwave"))
(custom-add-loads 'idlwave-external-programs '("idlwave"))
(custom-add-loads 'idlwave-routine-info '("idlwave"))
(custom-add-loads 'idlwave-documentation '("idlwave"))
(custom-add-loads 'idlwave-shell-general-setup '("idlw-shell" "idlwave"))
(custom-add-loads 'idlwave-misc '("idlwave"))
(custom-add-loads 'idlwave-code-formatting '("idlwave"))
(custom-add-loads 'idlwave-shell-command-setup '("idlw-shell"))
(custom-add-loads 'idlwave-online-help '("idlw-help"))
(custom-add-loads 'languages '("idlwave"))
(custom-add-loads 'idlwave-completion '("idlwave"))

;;; custom-load.el ends here
